@@ -241,7 +241,7 @@ qx.Class.define("callbackery.ui.Login", {
                 document.body.appendChild(iframe);
             }
             iframe.setAttribute('src',
-                '/login?nocache='+Math.round(1000000*Math.random()).toString(16));
+                'login?nocache='+Math.round(1000000*Math.random()).toString(16));
             return iframe;
         },
         __getIframeDocument: function(){
